pub struct HandshakeResponse {
pub channel: String,
pub successful: bool,
pub version: String,
pub minimum_version: Option<String>,
pub client_id: String,
pub supported_connection_types: Vec<String>,
pub advice: Option<Advice>,
pub ext: Option<Value>,
pub id: Option<String>,
pub auth_successful: Option<bool>,
}Expand description
This response is returned upon a successful handshake request.
Fields
channel: Stringsuccessful: boolversion: Stringminimum_version: Option<String>client_id: Stringsupported_connection_types: Vec<String>advice: Option<Advice>ext: Option<Value>id: Option<String>auth_successful: Option<bool>Trait Implementations
Sourceimpl Clone for HandshakeResponse
impl Clone for HandshakeResponse
Sourcefn clone(&self) -> HandshakeResponse
fn clone(&self) -> HandshakeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HandshakeResponse
impl Debug for HandshakeResponse
Sourceimpl<'de> Deserialize<'de> for HandshakeResponse
impl<'de> Deserialize<'de> for HandshakeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for HandshakeResponse
impl PartialEq for HandshakeResponse
Sourcefn eq(&self, other: &HandshakeResponse) -> bool
fn eq(&self, other: &HandshakeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for HandshakeResponse