pub struct PublishResponse {
pub channel: String,
pub client_id: String,
pub successful: bool,
pub error: Option<String>,
pub advice: Option<Advice>,
pub ext: Option<Value>,
pub data: Value,
pub id: Option<String>,
}Expand description
This response is returned upon a successful publish request.
Fields
channel: Stringclient_id: Stringsuccessful: boolerror: Option<String>advice: Option<Advice>ext: Option<Value>data: Valueid: Option<String>Trait Implementations
Sourceimpl Clone for PublishResponse
impl Clone for PublishResponse
Sourcefn clone(&self) -> PublishResponse
fn clone(&self) -> PublishResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublishResponse
impl Debug for PublishResponse
Sourceimpl<'de> Deserialize<'de> for PublishResponse
impl<'de> Deserialize<'de> for PublishResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PublishResponse
impl PartialEq for PublishResponse
Sourcefn eq(&self, other: &PublishResponse) -> bool
fn eq(&self, other: &PublishResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PublishResponse